<?PHP

/* Poidsy 0.2 - http://chris.smith.name/projects/poidsy
 * Copyright (c) 2008 Chris Smith
 *
 * Permission is hereby granted, free of charge, to any person obtaining a copy
 * of this software and associated documentation files (the "Software"), to deal
 * in the Software without restriction, including without limitation the rights
 * to use, copy, modify, merge, publish, distribute, sublicense, and/or sell
 * copies of the Software, and to permit persons to whom the Software is
 * furnished to do so, subject to the following conditions:
 *
 * The above copyright notice and this permission notice shall be included in
 * all copies or substantial portions of the Software.
 *
 * THE SOFTWARE IS PROVIDED "AS IS", WITHOUT WARRANTY OF ANY KIND, EXPRESS OR
 * IMPLIED, INCLUDING BUT NOT LIMITED TO THE WARRANTIES OF MERCHANTABILITY,
 * FITNESS FOR A PARTICULAR PURPOSE AND NONINFRINGEMENT. IN NO EVENT SHALL THE
 * AUTHORS OR COPYRIGHT HOLDERS BE LIABLE FOR ANY CLAIM, DAMAGES OR OTHER
 * LIABILITY, WHETHER IN AN ACTION OF CONTRACT, TORT OR OTHERWISE, ARISING FROM,
 * OUT OF OR IN CONNECTION WITH THE SOFTWARE OR THE USE OR OTHER DEALINGS IN THE
 * SOFTWARE.
 */

 // Poidsy returns its results in a session variable, so we need to start the
 // session here in order to get access to the results
 session_start();

 if (isset($_POST['openid_url']) || isset($_REQUEST['openid_mode'])) {
  // There are two cases when poidsy's processor needs to be invoked - firstly,
  // when the user has just submitted an OpenID identifier to be verified, in
  // which case $_POST['openid_url'] will be present (poidsy has special
  // handling for inputs named openid_url. If you want to use a URL from
  // another source, you can define the OPENID_URL constant instead.).
  // Secondly, if the user is being redirected back from their provider, the
  // openid.mode parameter will be present (which PHP translates to openid_mode)

  require('processor.php');

 } else {
  // If we don't have any processing to be doing, show them the form and
  // results.

?>
<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01//EN"
                      "http://www.w3.org/TR/html4/strict.dtd">
<html>
 <head>
  <title>OpenID consumer demonstration</title>
  <style type="text/css">
   input#openid_url {
    background: url('openid.gif') no-repeat; padding-left: 20px;
   }

   p { padding-left: 10px; }
   p.error { border-left: 10px solid #f00; }
   p.succ { border-left: 10px solid #0f0; }
  </style>
 </head>
 <body>
  <h1>OpenID consumer demo</h1>
<?PHP

 if (isset($_SESSION['openid']['error'])) {

  // If the error variable is set, it means that poidsy has encountered an
  // error while trying to validate the identifier. We just tell the user
  // what went wrong, and unset the session vars so the messages don't persist

  echo '<p class="error">An error occured: ', htmlentities($_SESSION['openid']['error']), '</p>';
  unset($_SESSION['openid']['error']);

 } else if (isset($_SESSION['openid']['validated']) && $_SESSION['openid']['validated']) {

  // Upon a successful validation, the validated field will have been set to
  // true. It's important to check the validated field, as the identity
  // will be specified in the array throughout the process, so it would be
  // possible for the user to request the page with an identity specified
  // but before Poidsy had validated it. As above, we unset the session
  // vars so that the details don't persist.

  echo '<p class="succ">Success: your OpenID identifier is <em>', htmlentities($_SESSION['openid']['identity']), '</em></p>';
  unset($_SESSION['openid']['validated']);

 }
?>
  <form action="<?PHP

 // We use URLBuilder::getCurrentURL() here merely to show how poidsy
 // redirects back to the original page. If you access this page as
 // demo.php?foo=bar, when the authentication process has finished, the
 // user will end up back at demo.php?foo=bar (in previous versions of
 // poidsy, it blindly stripped all GET arguments). In normal usage, you'll
 // probably just hard-code the form action.
 require_once(dirname(__FILE__) . '/urlbuilder.inc.php');
 echo htmlentities(URLBuilder::getCurrentURL());

?>" method="post">
   <input type="text" name="openid_url" id="openid_url">
   <input type="submit" value="Login">
  </form>
 </body>
</html>
<?PHP
 }
?>
